@@ -1,5 +1,9 @@
-#ifndef FILTERACTIONSENDRECEIPTTEST_H
-#define FILTERACTIONSENDRECEIPTTEST_H
+/*
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+
+  SPDX-License-Identifier: GPL-2.0-only
+*/
+#pragma once
 
 #include <QObject>
 
@@ -7,11 +11,10 @@ class FilterActionSendReceiptTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit FilterActionSendReceiptTest(QObject *parent = Q_NULLPTR);
+    explicit FilterActionSendReceiptTest(QObject *parent = nullptr);
 private Q_SLOTS:
     void shouldBeNotEmpty();
     void shouldRequiresPart();
     void shouldSieveRequires();
 };
 
-#endif // FILTERACTIONSENDRECEIPTTEST_H
