@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERIMPORTERPATHCACHETEST_H
-#define FILTERIMPORTERPATHCACHETEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class FilterImporterPathCacheTest : public QObject
     Q_OBJECT
 public:
     explicit FilterImporterPathCacheTest(QObject *parent = nullptr);
-    ~FilterImporterPathCacheTest();
+    ~FilterImporterPathCacheTest() override;
 private Q_SLOTS:
     void shouldReturnEmptyStringWhenListIsEmpty();
     void shouldNotStoreEmptyValue();
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void shouldReturnValues();
 };
 
-#endif // FILTERIMPORTERPATHCACHETEST_H
