@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef INVALIDFILTERINFOTEST_H
-#define INVALIDFILTERINFOTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,7 +13,7 @@ class InvalidFilterInfoTest : public QObject
     Q_OBJECT
 public:
     explicit InvalidFilterInfoTest(QObject *parent = nullptr);
-    ~InvalidFilterInfoTest();
+    ~InvalidFilterInfoTest() override;
 private Q_SLOTS:
     void shouldAddEmptyValue();
     void shouldAssignValueFromConstructor();
@@ -22,4 +21,3 @@ private Q_SLOTS:
     void shouldBeEqual();
 };
 
-#endif // INVALIDFILTERINFOTEST_H
