@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef INVALIDFILTERLISTWIDGETTEST_H
-#define INVALIDFILTERLISTWIDGETTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -14,10 +13,9 @@ class InvalidFilterListWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit InvalidFilterListWidgetTest(QObject *parent = nullptr);
-    ~InvalidFilterListWidgetTest();
+    ~InvalidFilterListWidgetTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldAddInvalidFilters();
 };
 
-#endif // INVALIDFILTERLISTWIDGETTEST_H
